@@ -81,7 +81,7 @@ class GuardianService(BaseService):
         """
         Return the last known location of the guardian's children.
 
-        This function retrieve the list of the guardian's children who are
+        This function retrieves the list of the guardian's children who are
         currently checked-in in a school bus, and return the location of the
         ID-R devices that were used to check-in these children.
 
@@ -99,6 +99,12 @@ class GuardianService(BaseService):
             * `attendant_account_id` (required): Identification of the attendant who
               checked-in the child.
 
+            * `bearing` (optional): Bearing in degrees of the last known location of
+              the child.  Bearing is the horizontal direction of travel of the
+              child, and is not related to the child orientation.  It is guaranteed
+              to be in the range `[0.0, 360.0]`, or not given if the bearing of the
+              child at its last known location is not provided.
+
             * `bus_id` (optional): Identification of the school bus where the child
               has been checked-in.
 
@@ -123,6 +129,8 @@ class GuardianService(BaseService):
             * `line_id` (optional): Identification of the school bus line for which
               the child has been checked-in.
 
+            * `speed` (optional): Speed in meters/second over the ground.
+
             * `stop_id` (optional): Identification of the bus stop where the child
               boarded school bus when the attendant checked-in this child.
         """
